@@ -1,13 +1,12 @@
 #![no_std]
 #![cfg_attr(docsrs, feature(doc_cfg))]
-#![forbid(unsafe_code, clippy::unwrap_used)]
-#![warn(missing_docs, rust_2018_idioms, unused_qualifications)]
+#![doc = include_str!("../README.md")]
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/RustCrypto/media/8f1a9894/logo.svg",
-    html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/media/8f1a9894/logo.svg",
-    html_root_url = "https://docs.rs/elliptic-curve/0.11.12"
+    html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/media/8f1a9894/logo.svg"
 )]
-#![doc = include_str!("../README.md")]
+#![forbid(unsafe_code, clippy::unwrap_used)]
+#![warn(missing_docs, rust_2018_idioms, unused_qualifications)]
 
 //! ## Usage
 //!
@@ -93,10 +92,6 @@ pub mod ecdh;
 #[cfg(feature = "jwk")]
 mod jwk;
 
-#[cfg(feature = "hash2curve")]
-#[doc(hidden)]
-pub mod hash2field;
-
 #[cfg(feature = "hash2curve")]
 #[cfg_attr(docsrs, doc(cfg(feature = "hash2curve")))]
 pub mod hash2curve;
@@ -135,10 +130,7 @@ pub use crate::scalar::ScalarBits;
 pub use crate::jwk::{JwkEcKey, JwkParameters};
 
 #[cfg(feature = "pkcs8")]
-pub use ::sec1::pkcs8;
-
-#[cfg(feature = "serde")]
-pub use serde;
+pub use pkcs8;
 
 use core::fmt::Debug;
 use generic_array::GenericArray;
@@ -150,7 +142,7 @@ use generic_array::GenericArray;
 #[cfg(feature = "pkcs8")]
 #[cfg_attr(docsrs, doc(cfg(feature = "pkcs8")))]
 pub const ALGORITHM_OID: pkcs8::ObjectIdentifier =
-    pkcs8::ObjectIdentifier::new("1.2.840.10045.2.1");
+    pkcs8::ObjectIdentifier::new_unwrap("1.2.840.10045.2.1");
 
 /// Elliptic curve.
 ///
@@ -202,27 +194,6 @@ pub type AffinePoint<C> = <C as AffineArithmetic>::AffinePoint;
 #[cfg_attr(docsrs, doc(cfg(feature = "arithmetic")))]
 pub type ProjectivePoint<C> = <C as ProjectiveArithmetic>::ProjectivePoint;
 
-/// Associate an [`ObjectIdentifier`][`pkcs8::ObjectIdentifier`] (OID) with an
-/// elliptic curve algorithm implementation.
-///
-/// This is used as as the `parameters` of an `AlgorithmIdentifier` as
-/// described in RFC 5280 Section 4.1.1.2:
-/// <https://tools.ietf.org/html/rfc5280#section-4.1.1.2>
-#[cfg(feature = "pkcs8")]
-#[cfg_attr(docsrs, doc(cfg(feature = "pkcs8")))]
-pub trait AlgorithmParameters: Curve {
-    /// Object Identifier (OID) for this curve
-    const OID: pkcs8::ObjectIdentifier;
-
-    /// Get the [`pkcs8::AlgorithmIdentifier`] for this curve
-    fn algorithm_identifier() -> pkcs8::AlgorithmIdentifier<'static> {
-        pkcs8::AlgorithmIdentifier {
-            oid: ALGORITHM_OID,
-            parameters: Some((&Self::OID).into()),
-        }
-    }
-}
-
 /// Elliptic curve parameters used by VOPRF.
 #[cfg(feature = "voprf")]
 #[cfg_attr(docsrs, doc(cfg(feature = "voprf")))]
